package sun.net.ftp;

import java.util.Iterator;
import java.util.Date;
import java.util.List;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.SocketAddress;
import java.net.Proxy;
import java.io.IOException;
import java.net.InetSocketAddress;
import java.io.Closeable;

public abstract class FtpClient implements Closeable
{
    private static final int FTP_PORT = 21;
    
    public static final int defaultPort() {
        return 21;
    }
    
    protected FtpClient() {
    }
    
    public static FtpClient create() {
        return FtpClientProvider.provider().createFtpClient();
    }
    
    public static FtpClient create(InetSocketAddress inetSocketAddress) throws FtpProtocolException, IOException {
        FtpClient create = create();
        if (inetSocketAddress != null) {
            create.connect(inetSocketAddress);
            return create;
        }
        return create;
    }
    
    public static FtpClient create(String hostname) throws FtpProtocolException, IOException {
        return create(new InetSocketAddress(hostname, 21));
    }
    
    public abstract FtpClient enablePassiveMode(boolean p0);
    
    public abstract boolean isPassiveModeEnabled();
    
    public abstract FtpClient setConnectTimeout(int p0);
    
    public abstract int getConnectTimeout();
    
    public abstract FtpClient setReadTimeout(int p0);
    
    public abstract int getReadTimeout();
    
    public abstract FtpClient setProxy(Proxy p0);
    
    public abstract Proxy getProxy();
    
    public abstract boolean isConnected();
    
    public abstract FtpClient connect(SocketAddress p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient connect(SocketAddress p0, int p1) throws FtpProtocolException, IOException;
    
    public abstract SocketAddress getServerAddress();
    
    public abstract FtpClient login(String p0, char[] p1) throws FtpProtocolException, IOException;
    
    public abstract FtpClient login(String p0, char[] p1, String p2) throws FtpProtocolException, IOException;
    
    @Override
    public abstract void close() throws IOException;
    
    public abstract boolean isLoggedIn();
    
    public abstract FtpClient changeDirectory(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient changeToParentDirectory() throws FtpProtocolException, IOException;
    
    public abstract String getWorkingDirectory() throws FtpProtocolException, IOException;
    
    public abstract FtpClient setRestartOffset(long p0);
    
    public abstract FtpClient getFile(String p0, OutputStream p1) throws FtpProtocolException, IOException;
    
    public abstract InputStream getFileStream(String p0) throws FtpProtocolException, IOException;
    
    public OutputStream putFileStream(String s) throws FtpProtocolException, IOException {
        return this.putFileStream(s, false);
    }
    
    public abstract OutputStream putFileStream(String p0, boolean p1) throws FtpProtocolException, IOException;
    
    public FtpClient putFile(String s, InputStream inputStream) throws FtpProtocolException, IOException {
        return this.putFile(s, inputStream, false);
    }
    
    public abstract FtpClient putFile(String p0, InputStream p1, boolean p2) throws FtpProtocolException, IOException;
    
    public abstract FtpClient appendFile(String p0, InputStream p1) throws FtpProtocolException, IOException;
    
    public abstract FtpClient rename(String p0, String p1) throws FtpProtocolException, IOException;
    
    public abstract FtpClient deleteFile(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient makeDirectory(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient removeDirectory(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient noop() throws FtpProtocolException, IOException;
    
    public abstract String getStatus(String p0) throws FtpProtocolException, IOException;
    
    public abstract List<String> getFeatures() throws FtpProtocolException, IOException;
    
    public abstract FtpClient abort() throws FtpProtocolException, IOException;
    
    public abstract FtpClient completePending() throws FtpProtocolException, IOException;
    
    public abstract FtpClient reInit() throws FtpProtocolException, IOException;
    
    public abstract FtpClient setType(FtpClient.TransferType p0) throws FtpProtocolException, IOException;
    
    public FtpClient setBinaryType() throws FtpProtocolException, IOException {
        this.setType(FtpClient.TransferType.BINARY);
        return this;
    }
    
    public FtpClient setAsciiType() throws FtpProtocolException, IOException {
        this.setType(FtpClient.TransferType.ASCII);
        return this;
    }
    
    public abstract InputStream list(String p0) throws FtpProtocolException, IOException;
    
    public abstract InputStream nameList(String p0) throws FtpProtocolException, IOException;
    
    public abstract long getSize(String p0) throws FtpProtocolException, IOException;
    
    public abstract Date getLastModified(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient setDirParser(FtpDirParser p0);
    
    public abstract Iterator<FtpDirEntry> listFiles(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient useKerberos() throws FtpProtocolException, IOException;
    
    public abstract String getWelcomeMsg();
    
    public abstract FtpReplyCode getLastReplyCode();
    
    public abstract String getLastResponseString();
    
    public abstract long getLastTransferSize();
    
    public abstract String getLastFileName();
    
    public abstract FtpClient startSecureSession() throws FtpProtocolException, IOException;
    
    public abstract FtpClient endSecureSession() throws FtpProtocolException, IOException;
    
    public abstract FtpClient allocate(long p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient structureMount(String p0) throws FtpProtocolException, IOException;
    
    public abstract String getSystem() throws FtpProtocolException, IOException;
    
    public abstract String getHelp(String p0) throws FtpProtocolException, IOException;
    
    public abstract FtpClient siteCmd(String p0) throws FtpProtocolException, IOException;
    
    public enum TransferType
    {
        ASCII, 
        BINARY, 
        EBCDIC;
    }
}
